@@ -7,6 +7,7 @@ import (
 	"github.com/navidrome/navidrome/model"
 	"github.com/navidrome/navidrome/model/request"
 	"github.com/navidrome/navidrome/server/subsonic/responses"
+	"github.com/navidrome/navidrome/utils/slice"
 )
 
 // buildUserResponse creates a User response object from a User model
@@ -19,6 +20,7 @@ func buildUserResponse(user model.User) responses.User {
 		ScrobblingEnabled: true,
 		DownloadRole:      conf.Server.EnableDownloads,
 		ShareRole:         conf.Server.EnableSharing,
+		Folder:            slice.Map(user.Libraries, func(lib model.Library) int32 { return int32(lib.ID) }),
 	}
 
 	if conf.Server.Jukebox.Enabled {
@@ -28,7 +30,6 @@ func buildUserResponse(user model.User) responses.User {
 	return userResponse
 }
 
-// TODO This is a placeholder. The real one has to read this info from a config file or the database
 func (api *Router) GetUser(r *http.Request) (*responses.Subsonic, error) {
 	loggedUser, ok := request.UserFrom(r.Context())
 	if !ok {
